#include <fstream>
#include <iomanip>
#include <algorithm>
#include <limits>
#include <cmath>

using namespace std;


const double Eps = 1e-16;

class Point
{
public:
  double x;
  double y;

  Point() { /* Do Nothing */ }

  Point(const double x, const double y)
  {
    Point::x = x;
    Point::y = y;
  }

  double product(const Point &a, const Point &b)
  {
    return (a.x - x) * (b.y - y) - (a.y - y) * (b.x - x);
  }

  double distToSegment(const Point &a, const Point &b)
  {
    const Point segment(b.x - a.x, b.y - a.y);
    const Point begin(x - a.x, y - a.y);
    double t = segment.x * begin.x + segment.y * begin.y;
    t /= segment.x * segment.x + segment.y * segment.y;
    if (t < -Eps)
      return dist(*this, a);
    if (t > 1 + Eps)
      return dist(*this, b);
    return dist(*this, Point(a.x + t * segment.x, a.y + t * segment.y));
  }

  bool isBelongToLine(const Point &a, const Point &b)
  {
    return abs((x - a.x) * (b.y - a.y) - (y - a.y) * (b.x - a.x)) <= Eps;
  }

  bool isBelongToSegment(const Point &a, const Point &b)
  {
    if (!isBelongToLine(a, b))
      return false;

    double t = x - a.x;
    double z = b.x - a.x;
    if (abs(z) > Eps)
    {
      t /= z;
      return t >= -Eps && t <= 1 + Eps;
    }
    else
    {
      bool inRange;
      if (a.y > b.y)
        inRange = (y >= b.y - Eps && y <= a.y + Eps);
      else
        inRange = (y >= a.y - Eps && y <= b.y + Eps);
      return inRange && abs(x - a.x) <= Eps;
    }
  }

  friend double dist(const Point &a, const Point &b)
  {
    return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
  }

  friend istream &operator >> (istream &stream, Point &p)
  {
    return stream >> p.x >> p.y;
  }

  friend ostream &operator << (ostream &stream, const Point &p)
  {
    stream << fixed << setprecision(6) << p.x << ' ';
    stream << fixed << setprecision(6) << p.y;
    return stream;
  }
};


ifstream cin("input.txt");
ofstream cout("output.txt");

double wastageField;
double wastageRoad;
Point start;
Point finish;
Point roadStart;
Point roadFinish;


int main()
{
  cin >> start >> finish;
  cin >> roadStart >> roadFinish;
  cin >> wastageField >> wastageRoad;

  double result = wastageField * dist(start, finish);
  if (
    roadStart.product(roadFinish, start) *
    roadStart.product(roadFinish, finish) < 0 &&
    start.product(finish, roadStart) *
    start.product(finish, roadFinish) < 0)
  {
    result += wastageRoad;
    double distField = dist(start, roadStart) + dist(roadStart, finish);
    result = min(result, wastageField * distField);
    distField = dist(start, roadFinish) + dist(roadFinish, finish);
    result = min(result, wastageField * distField);
  }
  if (
    roadStart.isBelongToSegment(start, finish) &&
    roadFinish.isBelongToSegment(start, finish))
  {
    double distStart = min(dist(start, roadStart), dist(start, roadFinish));
    double distFinish = min(dist(finish, roadStart), dist(finish, roadFinish));
    result = min(result, wastageRoad + wastageField * (distStart + distFinish));
    result = min(result, wastageField * dist(start, finish));
  }
  double distField = start.distToSegment(roadStart, roadFinish);
  distField += finish.distToSegment(roadStart, roadFinish);
  result = min(result, wastageRoad + wastageField * distField);

  cout << fixed << setprecision(6) << result << endl;
  return 0;
}
