#include <iostream>
#include <iomanip>
#include <algorithm>
#include <assert.h>
#include <math.h>

#define sqr(x) ((x)*(x))

using namespace std;

const double eps = 1e-10;

struct Point{
  double x, y;

  Point(const double& xx = 0, const double& yy = 0){
    x = xx; y = yy;
  }

  Point(const Point& a){
    x = a.x; y = a.y;
  }

  Point operator -(const Point& a) const{
    return Point(x - a.x, y - a.y);
  }

  double Length() const{
    return sqrt(sqr(x) + sqr(y));
  }

  bool operator !=(const Point& a) const{
    return x != a.x || y != a.y;
  }

  friend istream& operator >>(istream& in, Point& point){
    in >> point.x >> point.y;
    return in;
  }
};

struct Line{
  int a, b, c;

  Line(){
    a = b = c = 0;
  }

  Line(const Point& p1, const Point& p2){
    a = int(p2.y) - int(p1.y);
    b = int(p1.x) - int(p2.x);
    c = int(p1.y)*int(p2.x) - int(p1.x)*int(p2.y);
  }

  Point NearestPointTo(const Point& p) const{
    double lambda = - (a*p.x + b*p.y + c) / double(sqr(a) + sqr(b));
    return Point(p.x + lambda*a, p.y + lambda*b);
  }
};

int det(const int& a, const int& b, const int& c, const int& d){
  return a*d - b*c;
}

bool is_parallel(const Line& l1, const Line& l2){
  return det(l1.a, l1.b, l2.a, l2.b) == 0;
}

Point cross(const Line& l1, const Line& l2){
  int d = det(l1.a, l1.b, l2.a, l2.b);
  int dx = det(-l1.c, l1.b, -l2.c, l2.b);
  int dy = det(l1.a, -l1.c, l2.a, -l2.c);
  return Point(dx/double(d), dy/double(d));
}

double innerproduct(const Point& p1, const Point& p2){
  return p1.x*p2.x + p1.y*p2.y;
}

bool is_on_segment(const Point& a, const Point& b, const Point& c){
  Point v1(a-c);
  Point v2(b-c);
  return innerproduct(v1, v2) / double(v1.Length() * v2.Length()) <= -1 + eps;
};

double dist(const Point& a, const Point& b){
  return sqrt(sqr(a.x - b.x) + sqr(a.y - b.y));
}

int cost_field, cost_road;
double ans;
Point a, b, p1, p2;
Line ab, road;

void main(){
  ans = 1.0e308;
  freopen("input.txt", "r", stdin);
  freopen("output.txt", "w", stdout);
  cin >> a >> b >> p1 >> p2 >> cost_field >> cost_road;
  assert(a != b);
  assert(a != p1);
  assert(b != p1);
  assert(a != p2);
  assert(b != p2);
  assert(0 < cost_field && cost_field <= 1000);
  assert(0 < cost_road && cost_road <= 1000*1000);
  assert(!is_on_segment(p1, p2, a));
  assert(!is_on_segment(p1, p2, b));
  ab = Line(a, b); road = Line(p1, p2);
  if(!is_parallel(ab, road)){
    Point cross_point(cross(ab, road));
    Point nearest_to_a(road.NearestPointTo(a));
    Point nearest_to_b(road.NearestPointTo(b));
    if(!is_on_segment(a, b, cross_point) || !is_on_segment(p1, p2, cross_point)){
      ans = min(ans, dist(a, b) * cost_field);
    }
    if(is_on_segment(p1, p2, nearest_to_a) && is_on_segment(p1, p2, nearest_to_b)){
      ans = min(ans, (dist(a, nearest_to_a) + dist(b, nearest_to_b)) * cost_field + cost_road);
    }
    if(is_on_segment(p1, p2, nearest_to_a)){
      ans = min(ans, (dist(a, nearest_to_a) + min(dist(p1, b), dist(p2, b))) * cost_field + cost_road);
    }
    if(is_on_segment(p1, p2, nearest_to_b)){
      ans = min(ans, (dist(b, nearest_to_b) + min(dist(p1, a), dist(p2, a))) * cost_field + cost_road);
    }
  }else{
    ans = min(ans, dist(a, b) * cost_field);
  }
  ans = min(ans, (dist(a, p1) + dist(p1, b)) * cost_field);
  ans = min(ans, (dist(a, p2) + dist(p2, b)) * cost_field);
  ans = min(ans, (dist(a, p2) + dist(p1, b)) * cost_field + cost_road);
  ans = min(ans, (dist(a, p1) + dist(p2, b)) * cost_field + cost_road);
  cout << fixed << setprecision(15) << ans;
  fclose(stdin);
  fclose(stdout);
}
